//===-- C standard declarations for math.h ------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

#ifndef __LLVM_LIBC_DECLARATIONS_MATH_H
#define __LLVM_LIBC_DECLARATIONS_MATH_H

#ifndef __LIBC_ATTRS
#define __LIBC_ATTRS
#endif

#ifdef __cplusplus
extern "C" {
#endif

float acosf(float) __LIBC_ATTRS;

float acoshf(float) __LIBC_ATTRS;

double asin(double) __LIBC_ATTRS;

float asinf(float) __LIBC_ATTRS;

float asinhf(float) __LIBC_ATTRS;

double atan2(double, double) __LIBC_ATTRS;

float atan2f(float, float) __LIBC_ATTRS;

long double atan2l(long double, long double) __LIBC_ATTRS;

float atanf(float) __LIBC_ATTRS;

float atanhf(float) __LIBC_ATTRS;

int canonicalize(double, double) __LIBC_ATTRS;

int canonicalizef(float, float) __LIBC_ATTRS;

int canonicalizel(long double, long double) __LIBC_ATTRS;

double cbrt(double) __LIBC_ATTRS;

float cbrtf(float) __LIBC_ATTRS;

double ceil(double) __LIBC_ATTRS;

float ceilf(float) __LIBC_ATTRS;

long double ceill(long double) __LIBC_ATTRS;

double copysign(double, double) __LIBC_ATTRS;

float copysignf(float, float) __LIBC_ATTRS;

long double copysignl(long double, long double) __LIBC_ATTRS;

double cos(double) __LIBC_ATTRS;

float cosf(float) __LIBC_ATTRS;

float coshf(float) __LIBC_ATTRS;

long double ddivl(long double, long double) __LIBC_ATTRS;

double dmull(long double, long double) __LIBC_ATTRS;

double dsqrtl(long double) __LIBC_ATTRS;

float erff(float) __LIBC_ATTRS;

double exp(double) __LIBC_ATTRS;

double exp10(double) __LIBC_ATTRS;

float exp10f(float) __LIBC_ATTRS;

double exp2(double) __LIBC_ATTRS;

float exp2f(float) __LIBC_ATTRS;

float exp2m1f(float) __LIBC_ATTRS;

float expf(float) __LIBC_ATTRS;

double expm1(double) __LIBC_ATTRS;

float expm1f(float) __LIBC_ATTRS;

double fabs(double) __LIBC_ATTRS;

float fabsf(float) __LIBC_ATTRS;

long double fabsl(long double) __LIBC_ATTRS;

float fadd(double, double) __LIBC_ATTRS;

float faddl(long double, long double) __LIBC_ATTRS;

double fdim(double, double) __LIBC_ATTRS;

float fdimf(float, float) __LIBC_ATTRS;

long double fdiml(long double, long double) __LIBC_ATTRS;

float fdiv(double, double) __LIBC_ATTRS;

float fdivl(long double, long double) __LIBC_ATTRS;

float ffma(double, double, double) __LIBC_ATTRS;

float ffmal(long double, long double, long double) __LIBC_ATTRS;

double floor(double) __LIBC_ATTRS;

float floorf(float) __LIBC_ATTRS;

long double floorl(long double) __LIBC_ATTRS;

double fma(double, double, double) __LIBC_ATTRS;

float fmaf(float, float, float) __LIBC_ATTRS;

double fmax(double, double) __LIBC_ATTRS;

float fmaxf(float, float) __LIBC_ATTRS;

double fmaximum(double, double) __LIBC_ATTRS;

double fmaximum_mag(double, double) __LIBC_ATTRS;

double fmaximum_mag_num(double, double) __LIBC_ATTRS;

float fmaximum_mag_numf(float, float) __LIBC_ATTRS;

long double fmaximum_mag_numl(long double, long double) __LIBC_ATTRS;

float fmaximum_magf(float, float) __LIBC_ATTRS;

long double fmaximum_magl(long double, long double) __LIBC_ATTRS;

double fmaximum_num(double, double) __LIBC_ATTRS;

float fmaximum_numf(float, float) __LIBC_ATTRS;

long double fmaximum_numl(long double, long double) __LIBC_ATTRS;

float fmaximumf(float, float) __LIBC_ATTRS;

long double fmaximuml(long double, long double) __LIBC_ATTRS;

long double fmaxl(long double, long double) __LIBC_ATTRS;

double fmin(double, double) __LIBC_ATTRS;

float fminf(float, float) __LIBC_ATTRS;

double fminimum(double, double) __LIBC_ATTRS;

double fminimum_mag(double, double) __LIBC_ATTRS;

double fminimum_mag_num(double, double) __LIBC_ATTRS;

float fminimum_mag_numf(float, float) __LIBC_ATTRS;

long double fminimum_mag_numl(long double, long double) __LIBC_ATTRS;

float fminimum_magf(float, float) __LIBC_ATTRS;

long double fminimum_magl(long double, long double) __LIBC_ATTRS;

double fminimum_num(double, double) __LIBC_ATTRS;

float fminimum_numf(float, float) __LIBC_ATTRS;

float fminimumf(float, float) __LIBC_ATTRS;

long double fminimuml(long double, long double) __LIBC_ATTRS;

long double fminl(long double, long double) __LIBC_ATTRS;

double fmod(double, double) __LIBC_ATTRS;

float fmodf(float, float) __LIBC_ATTRS;

long double fmodl(long double, long double) __LIBC_ATTRS;

float fmul(double, double) __LIBC_ATTRS;

float fmull(long double, long double) __LIBC_ATTRS;

double frexp(double, int *) __LIBC_ATTRS;

float frexpf(float, int *) __LIBC_ATTRS;

long double frexpl(long double, int *) __LIBC_ATTRS;

float fsqrt(double) __LIBC_ATTRS;

float fsqrtl(long double) __LIBC_ATTRS;

float fsub(double, double) __LIBC_ATTRS;

float fsubl(long double, long double) __LIBC_ATTRS;

double getpayload(double *) __LIBC_ATTRS;

float getpayloadf(float *) __LIBC_ATTRS;

long double getpayloadl(long double *) __LIBC_ATTRS;

double hypot(double, double) __LIBC_ATTRS;

float hypotf(float, float) __LIBC_ATTRS;

int ilogb(double) __LIBC_ATTRS;

int ilogbf(float) __LIBC_ATTRS;

int ilogbl(long double) __LIBC_ATTRS;

int isnan(double) __LIBC_ATTRS;

int isnanf(float) __LIBC_ATTRS;

int isnanl(long double) __LIBC_ATTRS;

double ldexp(double, int) __LIBC_ATTRS;

float ldexpf(float, int) __LIBC_ATTRS;

long double ldexpl(long double, int) __LIBC_ATTRS;

double lgamma(double) __LIBC_ATTRS;

double lgamma_r(double, int *) __LIBC_ATTRS;

long llogb(double) __LIBC_ATTRS;

long llogbf(float) __LIBC_ATTRS;

long llogbl(long double) __LIBC_ATTRS;

long long llrint(double) __LIBC_ATTRS;

long long llrintf(float) __LIBC_ATTRS;

long long llrintl(long double) __LIBC_ATTRS;

long long llround(double) __LIBC_ATTRS;

long long llroundf(float) __LIBC_ATTRS;

long long llroundl(long double) __LIBC_ATTRS;

double log(double) __LIBC_ATTRS;

double log10(double) __LIBC_ATTRS;

float log10f(float) __LIBC_ATTRS;

double log1p(double) __LIBC_ATTRS;

float log1pf(float) __LIBC_ATTRS;

double log2(double) __LIBC_ATTRS;

float log2f(float) __LIBC_ATTRS;

double logb(double) __LIBC_ATTRS;

float logbf(float) __LIBC_ATTRS;

long double logbl(long double) __LIBC_ATTRS;

float logf(float) __LIBC_ATTRS;

long lrint(double) __LIBC_ATTRS;

long lrintf(float) __LIBC_ATTRS;

long lrintl(long double) __LIBC_ATTRS;

long lround(double) __LIBC_ATTRS;

long lroundf(float) __LIBC_ATTRS;

long lroundl(long double) __LIBC_ATTRS;

double modf(double, double *) __LIBC_ATTRS;

float modff(float, float *) __LIBC_ATTRS;

long double modfl(long double, long double *) __LIBC_ATTRS;

double nan(const char *) __LIBC_ATTRS;

float nanf(const char *) __LIBC_ATTRS;

long double nanl(const char *) __LIBC_ATTRS;

double nearbyint(double) __LIBC_ATTRS;

float nearbyintf(float) __LIBC_ATTRS;

long double nearbyintl(long double) __LIBC_ATTRS;

double nextafter(double, double) __LIBC_ATTRS;

float nextafterf(float, float) __LIBC_ATTRS;

long double nextafterl(long double, long double) __LIBC_ATTRS;

double nextdown(double) __LIBC_ATTRS;

float nextdownf(float) __LIBC_ATTRS;

long double nextdownl(long double) __LIBC_ATTRS;

double nexttoward(double, long double) __LIBC_ATTRS;

float nexttowardf(float, long double) __LIBC_ATTRS;

long double nexttowardl(long double, long double) __LIBC_ATTRS;

double nextup(double) __LIBC_ATTRS;

float nextupf(float) __LIBC_ATTRS;

long double nextupl(long double) __LIBC_ATTRS;

double pow(double, double) __LIBC_ATTRS;

float powf(float, float) __LIBC_ATTRS;

double powi(double, int) __LIBC_ATTRS;

float powif(float, int) __LIBC_ATTRS;

double remainder(double, double) __LIBC_ATTRS;

float remainderf(float, float) __LIBC_ATTRS;

long double remainderl(long double, long double) __LIBC_ATTRS;

double remquo(double, double, int *) __LIBC_ATTRS;

float remquof(float, float, int *) __LIBC_ATTRS;

long double remquol(long double, long double, int *) __LIBC_ATTRS;

double rint(double) __LIBC_ATTRS;

float rintf(float) __LIBC_ATTRS;

long double rintl(long double) __LIBC_ATTRS;

double round(double) __LIBC_ATTRS;

double roundeven(double) __LIBC_ATTRS;

float roundevenf(float) __LIBC_ATTRS;

long double roundevenl(long double) __LIBC_ATTRS;

float roundf(float) __LIBC_ATTRS;

long double roundl(long double) __LIBC_ATTRS;

double scalbln(double, long) __LIBC_ATTRS;

float scalblnf(float, long) __LIBC_ATTRS;

long double scalblnl(long double, long) __LIBC_ATTRS;

double scalbn(double, int) __LIBC_ATTRS;

float scalbnf(float, int) __LIBC_ATTRS;

long double scalbnl(long double, int) __LIBC_ATTRS;

int setpayload(double *, double) __LIBC_ATTRS;

int setpayloadf(float *, float) __LIBC_ATTRS;

int setpayloadl(long double *, long double) __LIBC_ATTRS;

double setpayloadsig(double *, double) __LIBC_ATTRS;

int setpayloadsigf(float *, float) __LIBC_ATTRS;

int setpayloadsigl(long double *, long double) __LIBC_ATTRS;

double sin(double) __LIBC_ATTRS;

void sincosf(float, float *, float *) __LIBC_ATTRS;

float sinf(float) __LIBC_ATTRS;

float sinhf(float) __LIBC_ATTRS;

double sqrt(double) __LIBC_ATTRS;

float sqrtf(float) __LIBC_ATTRS;

long double sqrtl(long double) __LIBC_ATTRS;

double tan(double) __LIBC_ATTRS;

float tanf(float) __LIBC_ATTRS;

float tanhf(float) __LIBC_ATTRS;

int totalorder(const double *, const double *) __LIBC_ATTRS;

int totalorderf(const float *, const float *) __LIBC_ATTRS;

int totalorderl(const long double *, const long double *) __LIBC_ATTRS;

int totalordermag(const double *, const double *) __LIBC_ATTRS;

int totalordermagf(const float *, const float *) __LIBC_ATTRS;

int totalordermagl(const long double *, const long double *) __LIBC_ATTRS;

double trunc(double) __LIBC_ATTRS;

float truncf(float) __LIBC_ATTRS;

long double truncl(long double) __LIBC_ATTRS;

int canonicalizef16(_Float16, _Float16) __LIBC_ATTRS;

_Float16 ceilf16(_Float16) __LIBC_ATTRS;

_Float16 copysignf16(_Float16, _Float16) __LIBC_ATTRS;

_Float16 coshf16(_Float16) __LIBC_ATTRS;

_Float16 exp10m1f16(_Float16) __LIBC_ATTRS;

_Float16 f16add(double, double) __LIBC_ATTRS;

_Float16 f16addf(float, float) __LIBC_ATTRS;

_Float16 f16addl(long double, long double) __LIBC_ATTRS;

_Float16 f16div(double, double) __LIBC_ATTRS;

_Float16 f16divf(float, float) __LIBC_ATTRS;

_Float16 f16divl(long double, long double) __LIBC_ATTRS;

_Float16 f16fma(double, double, double) __LIBC_ATTRS;

_Float16 f16fmaf(float, float, float) __LIBC_ATTRS;

_Float16 f16fmal(long double, long double, long double) __LIBC_ATTRS;

_Float16 f16mul(double, double) __LIBC_ATTRS;

_Float16 f16mulf(float, float) __LIBC_ATTRS;

_Float16 f16mull(long double, long double) __LIBC_ATTRS;

_Float16 f16sqrt(double) __LIBC_ATTRS;

_Float16 f16sqrtf(float) __LIBC_ATTRS;

_Float16 f16sqrtl(long double) __LIBC_ATTRS;

_Float16 f16sub(double, double) __LIBC_ATTRS;

_Float16 f16subf(float, float) __LIBC_ATTRS;

_Float16 f16subl(long double, long double) __LIBC_ATTRS;

_Float16 fabsf16(_Float16) __LIBC_ATTRS;

_Float16 fdimf16(_Float16, _Float16) __LIBC_ATTRS;

_Float16 floorf16(_Float16) __LIBC_ATTRS;

_Float16 fmaxf16(_Float16, _Float16) __LIBC_ATTRS;

_Float16 fmaximum_mag_numf16(_Float16, _Float16) __LIBC_ATTRS;

_Float16 fmaximum_magf16(_Float16, _Float16) __LIBC_ATTRS;

_Float16 fmaximum_numf16(_Float16, _Float16) __LIBC_ATTRS;

_Float16 fmaximumf16(_Float16, _Float16) __LIBC_ATTRS;

_Float16 fminf16(_Float16, _Float16) __LIBC_ATTRS;

_Float16 fminimum_mag_numf16(_Float16, _Float16) __LIBC_ATTRS;

_Float16 fminimum_magf16(_Float16, _Float16) __LIBC_ATTRS;

_Float16 fminimum_numf16(_Float16, _Float16) __LIBC_ATTRS;

_Float16 fminimumf16(_Float16, _Float16) __LIBC_ATTRS;

_Float16 fmodf16(_Float16, _Float16) __LIBC_ATTRS;

_Float16 frexpf16(_Float16, int *) __LIBC_ATTRS;

_Float16 fromfpf16(_Float16, int, unsigned int) __LIBC_ATTRS;

_Float16 fromfpxf16(_Float16, int, unsigned int) __LIBC_ATTRS;

_Float16 getpayloadf16(_Float16 *) __LIBC_ATTRS;

int ilogbf16(_Float16) __LIBC_ATTRS;

_Float16 ldexpf16(_Float16, int) __LIBC_ATTRS;

long llogbf16(_Float16) __LIBC_ATTRS;

long long llrintf16(_Float16) __LIBC_ATTRS;

long long llroundf16(_Float16) __LIBC_ATTRS;

_Float16 log10f16(_Float16) __LIBC_ATTRS;

_Float16 log2f16(_Float16) __LIBC_ATTRS;

_Float16 logbf16(_Float16) __LIBC_ATTRS;

_Float16 logf16(_Float16) __LIBC_ATTRS;

long lrintf16(_Float16) __LIBC_ATTRS;

long lroundf16(_Float16) __LIBC_ATTRS;

_Float16 modff16(_Float16, _Float16 *) __LIBC_ATTRS;

_Float16 nanf16(const char *) __LIBC_ATTRS;

_Float16 nearbyintf16(_Float16) __LIBC_ATTRS;

_Float16 nextafterf16(_Float16, _Float16) __LIBC_ATTRS;

_Float16 nextdownf16(_Float16) __LIBC_ATTRS;

_Float16 nexttowardf16(_Float16, _Float16) __LIBC_ATTRS;

_Float16 nextupf16(_Float16) __LIBC_ATTRS;

_Float16 remainderf16(_Float16, _Float16) __LIBC_ATTRS;

_Float16 remquof16(_Float16, _Float16, int *) __LIBC_ATTRS;

_Float16 rintf16(_Float16) __LIBC_ATTRS;

_Float16 roundevenf16(_Float16) __LIBC_ATTRS;

_Float16 roundf16(_Float16) __LIBC_ATTRS;

_Float16 scalblnf16(_Float16, long) __LIBC_ATTRS;

_Float16 scalblnf16(_Float16, long) __LIBC_ATTRS;

_Float16 scalbnf16(_Float16, int) __LIBC_ATTRS;

int setpayloadf16(_Float16 *, _Float16) __LIBC_ATTRS;

int setpayloadsigf16(_Float16 *, _Float16) __LIBC_ATTRS;

_Float16 sinhf16(_Float16) __LIBC_ATTRS;

_Float16 sqrtf16(_Float16) __LIBC_ATTRS;

_Float16 tanhf16(_Float16) __LIBC_ATTRS;

int totalorderf16(const _Float16 *, const _Float16 *) __LIBC_ATTRS;

int totalordermagf16(const _Float16 *, const _Float16 *) __LIBC_ATTRS;

_Float16 truncf16(_Float16) __LIBC_ATTRS;

_Float16 ufromfpf16(_Float16, int, unsigned int) __LIBC_ATTRS;

_Float16 ufromfpxf16(_Float16, int, unsigned int) __LIBC_ATTRS;

#ifdef __cplusplus
}
#endif

#endif