//===-- C standard declarations for stdio.h ------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

#ifndef __LLVM_LIBC_DECLARATIONS_STDIO_H
#define __LLVM_LIBC_DECLARATIONS_STDIO_H

#ifndef __LIBC_ATTRS
#define __LIBC_ATTRS
#endif

#ifdef __cplusplus
extern "C" {
#endif

int asprintf(char **__restrict, const char *__restrict, ...) __LIBC_ATTRS;

void clearerr(FILE *) __LIBC_ATTRS;

int fclose(FILE *) __LIBC_ATTRS;

int feof(FILE *) __LIBC_ATTRS;

int ferror(FILE *) __LIBC_ATTRS;

int fflush(FILE *) __LIBC_ATTRS;

int fgetc(FILE *) __LIBC_ATTRS;

char * fgets(char *__restrict, int, FILE *__restrict) __LIBC_ATTRS;

FILE * fopen(const char *, const char *) __LIBC_ATTRS;

int fprintf(FILE *__restrict, const char *__restrict, ...) __LIBC_ATTRS;

int fputc(int, FILE *) __LIBC_ATTRS;

int fputs(const char *__restrict, FILE *__restrict) __LIBC_ATTRS;

size_t fread(void *__restrict, size_t, size_t, FILE *__restrict) __LIBC_ATTRS;

int fscanf(FILE *__restrict, const char *__restrict, ...) __LIBC_ATTRS;

int fseek(FILE *, long, int) __LIBC_ATTRS;

long ftell(FILE *) __LIBC_ATTRS;

size_t fwrite(const void *__restrict, size_t, size_t, FILE *__restrict) __LIBC_ATTRS;

int getc(FILE *) __LIBC_ATTRS;

int getchar(void) __LIBC_ATTRS;

int printf(const char *__restrict, ...) __LIBC_ATTRS;

int putc(int, FILE *) __LIBC_ATTRS;

int putchar(int) __LIBC_ATTRS;

int puts(const char *) __LIBC_ATTRS;

int remove(const char *) __LIBC_ATTRS;

int rename(const char *, const char *) __LIBC_ATTRS;

int scanf(const char *__restrict, ...) __LIBC_ATTRS;

int snprintf(char *__restrict, size_t, const char *__restrict, ...) __LIBC_ATTRS;

int sprintf(char *__restrict, const char *__restrict, ...) __LIBC_ATTRS;

int sscanf(const char *__restrict, const char *__restrict, ...) __LIBC_ATTRS;

int ungetc(int, FILE *) __LIBC_ATTRS;

int vasprintf(char **__restrict, const char *__restrict, va_list) __LIBC_ATTRS;

int vfprintf(FILE *__restrict, const char *__restrict, va_list) __LIBC_ATTRS;

int vfscanf(FILE *__restrict, const char *__restrict, va_list) __LIBC_ATTRS;

int vprintf(const char *__restrict, va_list) __LIBC_ATTRS;

int vscanf(const char *__restrict, va_list) __LIBC_ATTRS;

int vsnprintf(char *__restrict, size_t, const char *__restrict, va_list) __LIBC_ATTRS;

int vsprintf(char *__restrict, const char *__restrict, va_list) __LIBC_ATTRS;

int vsscanf(const char *__restrict, const char *__restrict, va_list) __LIBC_ATTRS;

extern FILE * stderr; __LIBC_ATTRS;

extern FILE * stdin; __LIBC_ATTRS;

extern FILE * stdout; __LIBC_ATTRS;

#ifdef __cplusplus
}
#endif

#endif