//===-- C standard declarations for stdlib.h ------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

#ifndef __LLVM_LIBC_DECLARATIONS_STDLIB_H
#define __LLVM_LIBC_DECLARATIONS_STDLIB_H

#ifndef __LIBC_ATTRS
#define __LIBC_ATTRS
#endif

#ifdef __cplusplus
extern "C" {
#endif

_Noreturn void _Exit(int) __LIBC_ATTRS;

_Noreturn void abort(void) __LIBC_ATTRS;

int abs(int) __LIBC_ATTRS;

void * aligned_alloc(size_t, size_t) __LIBC_ATTRS;

int at_quick_exit(__atexithandler_t) __LIBC_ATTRS;

int atexit(__atexithandler_t) __LIBC_ATTRS;

double atof(const char *__restrict) __LIBC_ATTRS;

int atoi(const char *) __LIBC_ATTRS;

long atol(const char *) __LIBC_ATTRS;

long long atoll(const char *) __LIBC_ATTRS;

void * bsearch(const void *, const void *, size_t, size_t, __bsearchcompare_t) __LIBC_ATTRS;

void * calloc(size_t, size_t) __LIBC_ATTRS;

div_t div(int, int) __LIBC_ATTRS;

_Noreturn void exit(int) __LIBC_ATTRS;

void free(void *) __LIBC_ATTRS;

char * getenv(const char *) __LIBC_ATTRS;

long labs(long) __LIBC_ATTRS;

ldiv_t ldiv(long, long) __LIBC_ATTRS;

long long llabs(long long) __LIBC_ATTRS;

lldiv_t lldiv(long long, long long) __LIBC_ATTRS;

void * malloc(size_t) __LIBC_ATTRS;

void qsort(void *, size_t, size_t, __qsortcompare_t) __LIBC_ATTRS;

void qsort_r(void *, size_t, size_t, __qsortrcompare_t, void *) __LIBC_ATTRS;

_Noreturn void quick_exit(int) __LIBC_ATTRS;

int rand(void) __LIBC_ATTRS;

void * realloc(void *, size_t) __LIBC_ATTRS;

void srand(unsigned int) __LIBC_ATTRS;

double strtod(const char *__restrict, char **__restrict) __LIBC_ATTRS;

double strtod_l(const char *__restrict, char **__restrict, locale_t) __LIBC_ATTRS;

float strtof(const char *__restrict, char **__restrict) __LIBC_ATTRS;

float strtof_l(const char *__restrict, char **__restrict, locale_t) __LIBC_ATTRS;

long strtol(const char *__restrict, char **__restrict, int) __LIBC_ATTRS;

long strtol_l(const char *__restrict, char **__restrict, int, locale_t) __LIBC_ATTRS;

long double strtold(const char *__restrict, char **__restrict) __LIBC_ATTRS;

long double strtold_l(const char *__restrict, char **__restrict, locale_t) __LIBC_ATTRS;

long long strtoll(const char *__restrict, char **__restrict, int) __LIBC_ATTRS;

long long strtoll_l(const char *__restrict, char **__restrict, int, locale_t) __LIBC_ATTRS;

unsigned long strtoul(const char *__restrict, char **__restrict, int) __LIBC_ATTRS;

unsigned long strtoul_l(const char *__restrict, char **__restrict, int, locale_t) __LIBC_ATTRS;

unsigned long long strtoull(const char *__restrict, char **__restrict, int) __LIBC_ATTRS;

unsigned long long strtoull_l(const char *__restrict, char **__restrict, int, locale_t) __LIBC_ATTRS;

int system(const char *) __LIBC_ATTRS;

#ifdef __cplusplus
}
#endif

#endif