//===-- C standard declarations for string.h ------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

#ifndef __LLVM_LIBC_DECLARATIONS_STRING_H
#define __LLVM_LIBC_DECLARATIONS_STRING_H

#ifndef __LIBC_ATTRS
#define __LIBC_ATTRS
#endif

#ifdef __cplusplus
extern "C" {
#endif

void * memccpy(void *__restrict, const void *__restrict, int, size_t) __LIBC_ATTRS;

void * memchr(const void *, int, size_t) __LIBC_ATTRS;

int memcmp(const void *, const void *, size_t) __LIBC_ATTRS;

void * memcpy(void *__restrict, const void *__restrict, size_t) __LIBC_ATTRS;

void * memmem(const void *, size_t, const void *, size_t) __LIBC_ATTRS;

void * memmove(void *, const void *, size_t) __LIBC_ATTRS;

void * mempcpy(void *__restrict, const void *__restrict, size_t) __LIBC_ATTRS;

void * memrchr(const void *, int, size_t) __LIBC_ATTRS;

void * memset(void *, int, size_t) __LIBC_ATTRS;

char * stpcpy(char *__restrict, const char *__restrict) __LIBC_ATTRS;

char * stpncpy(char *__restrict, const char *__restrict, size_t) __LIBC_ATTRS;

char * strcasestr(const char *, const char *) __LIBC_ATTRS;

char * strcat(char *__restrict, const char *__restrict) __LIBC_ATTRS;

char * strchr(const char *, int) __LIBC_ATTRS;

char * strchrnul(const char *, int) __LIBC_ATTRS;

int strcmp(const char *, const char *) __LIBC_ATTRS;

int strcoll(const char *, const char *) __LIBC_ATTRS;

int strcoll_l(const char *, const char *, locale_t) __LIBC_ATTRS;

char * strcpy(char *__restrict, const char *__restrict) __LIBC_ATTRS;

size_t strcspn(const char *, const char *) __LIBC_ATTRS;

char * strdup(const char *) __LIBC_ATTRS;

char * strerror(int) __LIBC_ATTRS;

size_t strlcat(char *__restrict, const char *__restrict, size_t) __LIBC_ATTRS;

size_t strlcpy(char *__restrict, const char *__restrict, size_t) __LIBC_ATTRS;

size_t strlen(const char *) __LIBC_ATTRS;

char * strncat(char *, const char *, size_t) __LIBC_ATTRS;

int strncmp(const char *, const char *, size_t) __LIBC_ATTRS;

char * strncpy(char *__restrict, const char *__restrict, size_t) __LIBC_ATTRS;

char * strndup(const char *, size_t) __LIBC_ATTRS;

size_t strnlen(const char *, size_t) __LIBC_ATTRS;

char * strpbrk(const char *, const char *) __LIBC_ATTRS;

char * strrchr(const char *, int) __LIBC_ATTRS;

char * strsep(char **__restrict, const char *__restrict) __LIBC_ATTRS;

size_t strspn(const char *, const char *) __LIBC_ATTRS;

char * strstr(const char *, const char *) __LIBC_ATTRS;

char * strtok(char *__restrict, const char *__restrict) __LIBC_ATTRS;

char * strtok_r(char *__restrict, const char *__restrict, char ** __restrict) __LIBC_ATTRS;

size_t strxfrm(char *__restrict, const char *__restrict, size_t) __LIBC_ATTRS;

size_t strxfrm_l(char *__restrict, const char *__restrict, size_t, locale_t) __LIBC_ATTRS;

#ifdef __cplusplus
}
#endif

#endif